@@ -1,5 +1,5 @@
 var image_cropping = {
-  $: jQuery.noConflict(),
+  $: jQuery.noConflict(true),
   init: function() {
     // set styles for size-warning
     var style_img_warning = 'div.jcrop-image.size-warning .jcrop-vline{border:1px solid red; background: none;}' +
@@ -52,6 +52,7 @@ var image_cropping = {
       var options = {
         aspectRatio: min_width/min_height,
         minSize: [5, 5],
+        keySupport: false,
         trueSize: [org_width, org_height],
         onSelect: image_cropping.update_selection($this),
         addClass: ($this.data('size-warning') && ((org_width < min_width) || (org_height < min_height))) ? 'size-warning jcrop-image': 'jcrop-image'
